@@ -21,7 +21,7 @@ import jinja2
 import jinja2.meta
 import jsonschema
 
-from rally.common.i18n import _, _LI
+from rally.common.i18n import _, _LI, _LE
 from rally.common import logging
 from rally.common import objects
 from rally import consts
@@ -57,7 +57,7 @@ class Deployment(object):
         try:
             deployer.validate()
         except jsonschema.ValidationError:
-            LOG.error(_("Deployment %s: Schema validation error.") %
+            LOG.error(_LE("Deployment %s: Schema validation error.") %
                       deployment["uuid"])
             deployment.update_status(consts.DeployStatus.DEPLOY_FAILED)
             raise
@@ -381,15 +381,18 @@ class Verification(object):
 
     @classmethod
     def verify(cls, deployment, set_name="", regex=None, tests_file=None,
-               tempest_config=None, expected_failures=None, system_wide=False,
-               concur=0, failing=False):
+               tests_file_to_skip=None, tempest_config=None,
+               expected_failures=None, system_wide=False, concur=0,
+               failing=False):
         """Start verification.
 
-        :param deployment: UUID or name of a deployment
         :param deployment: UUID or name of a deployment
         :param set_name: Name of a Tempest test set
         :param regex: Regular expression of test
         :param tests_file: Path to a file with a list of Tempest tests
+                           to run them
+        :param tests_file_to_skip: Path to a file with a list of Tempest tests
+                                   to skip them
         :param tempest_config: User specified Tempest config file location
         :param expected_failures: Dictionary with Tempest tests that are
                                   expected to fail. Keys are test names;
@@ -400,8 +403,7 @@ class Verification(object):
                             env when running the tests
         :param concur: How many processes to use to run Tempest tests.
                        The default value (0) auto-detects CPU count
-        :param failing: Re-run tests that failed during the last
-                        execution
+        :param failing: Re-run tests that failed during the last execution
         :returns: Verification object
         """
 
@@ -417,6 +419,7 @@ class Verification(object):
         LOG.info("Starting verification of deployment: %s" % deployment_uuid)
         verification.set_running()
         verifier.verify(set_name=set_name, regex=regex, tests_file=tests_file,
+                        tests_file_to_skip=tests_file_to_skip,
                         expected_failures=expected_failures, concur=concur,
                         failing=failing)
 
@@ -452,7 +455,8 @@ class Verification(object):
         :param source: Path/URL to repo to clone Tempest from
         :param version: Commit ID or tag to checkout before Tempest
                         installation
-        :param system_wide: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to install Tempest package and
+                            create a Tempest virtual env
         """
         deployment_uuid = objects.Deployment.get(deployment)["uuid"]
         verifier = tempest.Tempest(deployment_uuid, source=source,
@@ -478,7 +482,8 @@ class Verification(object):
         :param source: Path/URL to repo to clone Tempest from
         :param version: Commit ID or tag to checkout before Tempest
                         installation
-        :param system_wide: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to install Tempest package and
+                            create a Tempest virtual env
         """
         deployment_uuid = objects.Deployment.get(deployment)["uuid"]
         verifier = tempest.Tempest(deployment_uuid, source=source,
@@ -509,14 +514,45 @@ class Verification(object):
         verifier.install_plugin()
 
     @classmethod
-    def discover_tests(cls, deployment, pattern=""):
+    def list_tempest_plugins(cls, deployment, system_wide=False):
+        """List all installed Tempest plugins.
+
+        :param deployment: UUID or name of a deployment
+        :param system_wide: List all plugins installed in the local env or
+                            in Tempest virtual env
+        """
+        deployment_uuid = objects.Deployment.get(deployment)["uuid"]
+        verifier = tempest.Tempest(deployment_uuid, system_wide=system_wide)
+
+        cls._check_tempest_tree_existence(verifier)
+
+        return verifier.list_plugins()
+
+    @classmethod
+    def uninstall_tempest_plugin(cls, deployment, repo_name,
+                                 system_wide=False):
+        """Uninstall Tempest plugin.
+
+        :param deployment: UUID or name of a deployment
+        :param repo_name: Plugin repo name
+        :param system_wide: Uninstall plugin from Tempest virtual env or
+                            from the local env
+        """
+        deployment_uuid = objects.Deployment.get(deployment)["uuid"]
+        verifier = tempest.Tempest(deployment_uuid, system_wide=system_wide)
+        verifier.uninstall_plugin(repo_name)
+
+    @classmethod
+    def discover_tests(cls, deployment, pattern="", system_wide=False):
         """Get a list of discovered tests.
 
         :param deployment: UUID or name of a deployment
         :param pattern: Test name pattern which can be used to match
+        :param system_wide: Discover tests for system-wide or venv
+                            Tempest installation
         """
         deployment_uuid = objects.Deployment.get(deployment)["uuid"]
-        verifier = tempest.Tempest(deployment_uuid)
+        verifier = tempest.Tempest(deployment_uuid, system_wide=system_wide)
 
         cls._check_tempest_tree_existence(verifier)
 
@@ -524,11 +560,13 @@ class Verification(object):
 
     @classmethod
     def configure_tempest(cls, deployment, tempest_config=None,
-                          override=False):
-        """Generate configuration file of Tempest.
+                          extra_conf=None, override=False):
+        """Generate Tempest configuration file.
 
         :param deployment: UUID or name of a deployment
         :param tempest_config: User specified Tempest config file location
+        :param extra_conf: A ConfigParser() object with options to
+                           extend/update Tempest config file
         :param override: Whether or not to override existing Tempest
                          config file
         """
@@ -538,11 +576,11 @@ class Verification(object):
 
         cls._check_tempest_tree_existence(verifier)
 
-        verifier.generate_config_file(override)
+        verifier.generate_config_file(extra_conf, override)
 
     @classmethod
     def show_config_info(cls, deployment):
-        """Get information about configuration file of Tempest.
+        """Get information about Tempest configuration file.
 
         :param deployment: UUID or name of a deployment
         """
