@@ -67,6 +67,7 @@ class DeploymentCommands(object):
             OS_PASSWORD
             OS_AUTH_URL
             OS_TENANT_NAME
+            OS_ENDPOINT_TYPE or OS_INTERFACE
             OS_ENDPOINT
             OS_REGION_NAME
             OS_CACERT
@@ -253,24 +254,29 @@ class DeploymentCommands(object):
     def _update_openrc_deployment_file(self, deployment, credential):
         openrc_path = os.path.expanduser("~/.rally/openrc-%s" % deployment)
         with open(openrc_path, "w+") as env_file:
-            env_file.write("export OS_AUTH_URL=%(auth_url)s\n"
-                           "export OS_USERNAME=%(username)s\n"
-                           "export OS_PASSWORD=%(password)s\n"
-                           "export OS_TENANT_NAME=%(tenant_name)s\n"
+            env_file.write("export OS_AUTH_URL='%(auth_url)s'\n"
+                           "export OS_USERNAME='%(username)s'\n"
+                           "export OS_PASSWORD='%(password)s'\n"
+                           "export OS_TENANT_NAME='%(tenant_name)s'\n"
                            % credential)
             if credential.get("region_name"):
-                env_file.write("export OS_REGION_NAME=%s\n" %
+                env_file.write("export OS_REGION_NAME='%s'\n" %
                                credential["region_name"])
+            if credential.get("endpoint_type"):
+                env_file.write("export OS_ENDPOINT_TYPE='%sURL'\n" %
+                               credential["endpoint_type"])
+                env_file.write("export OS_INTERFACE='%s'\n" %
+                               credential["endpoint_type"])
             if credential.get("endpoint"):
-                env_file.write("export OS_ENDPOINT=%s\n" %
+                env_file.write("export OS_ENDPOINT='%s'\n" %
                                credential["endpoint"])
             if credential.get("https_cacert"):
-                env_file.write("export OS_CACERT=%s\n" %
+                env_file.write("export OS_CACERT='%s'\n" %
                                credential["https_cacert"])
             if re.match(r"^/v3/?$", parse.urlparse(
                     credential["auth_url"]).path) is not None:
-                env_file.write("export OS_USER_DOMAIN_NAME=%s\n"
-                               "export OS_PROJECT_DOMAIN_NAME=%s\n" %
+                env_file.write("export OS_USER_DOMAIN_NAME='%s'\n"
+                               "export OS_PROJECT_DOMAIN_NAME='%s'\n" %
                                (credential["user_domain_name"],
                                 credential["project_domain_name"]))
         expanded_path = os.path.expanduser("~/.rally/openrc")
@@ -295,13 +301,13 @@ class DeploymentCommands(object):
             self._update_openrc_deployment_file(
                 deployment["uuid"],
                 deployment["admin"] or deployment["users"][0])
-            print ("~/.rally/openrc was updated\n\nHINTS:\n"
-                   "* To get your cloud resources, run:\n\t"
-                   "rally show [flavors|images|keypairs|networks|secgroups]\n"
-                   "\n* To use standard OpenStack clients, set up your env by "
-                   "running:\n\tsource ~/.rally/openrc\n"
-                   "  OpenStack clients are now configured, e.g run:\n\t"
-                   "glance image-list")
+            print("~/.rally/openrc was updated\n\nHINTS:\n"
+                  "* To get your cloud resources, run:\n\t"
+                  "rally show [flavors|images|keypairs|networks|secgroups]\n"
+                  "\n* To use standard OpenStack clients, set up your env by "
+                  "running:\n\tsource ~/.rally/openrc\n"
+                  "  OpenStack clients are now configured, e.g run:\n\t"
+                  "openstack image list")
         except exceptions.DeploymentNotFound:
             print("Deployment %s is not found." % deployment)
             return 1
