@@ -20,6 +20,7 @@ import json
 import os
 
 import six
+from six.moves import configparser
 import yaml
 
 from rally import api
@@ -52,20 +53,34 @@ class VerifyCommands(object):
                         "Available sets are %s" % ", ".join(AVAILABLE_SETS))
     @cliutils.args("--regex", dest="regex", type=str, required=False,
                    help="Test name regular expression")
-    @cliutils.args("--tests-file", metavar="<path>", dest="tests_file",
+    @cliutils.args("--load-list", metavar="<path>", dest="tests_file",
                    type=str, required=False,
-                   help="Path to a file with a list of Tempest tests")
+                   help="Path to a file with a list of Tempest tests "
+                        "to run only them")
+    @cliutils.deprecated_args("--tests-file", metavar="<path>",
+                              dest="tests_file", type=str, required=False,
+                              help="Path to a file with a list of Tempest "
+                                   "tests to run only them", release="0.6.0")
+    @cliutils.args("--skip-list", metavar="<path>", dest="tests_file_to_skip",
+                   type=str, required=False,
+                   help="Path to a file with a list of Tempest tests "
+                        "to skip their run")
     @cliutils.args("--tempest-config", dest="tempest_config", type=str,
                    required=False, metavar="<path>",
                    help="User-specified Tempest config file location")
-    @cliutils.args("--xfails-file", dest="xfails_file", type=str,
+    @cliutils.args("--xfail-list", dest="xfails_file", type=str,
                    required=False, metavar="<path>",
-                   help="Path to a YAML file with a list of Tempest "
-                        "tests that are expected to fail")
+                   help="Path to a YAML file with a list of Tempest tests "
+                        "that are expected to fail")
+    @cliutils.deprecated_args("--xfails-file", dest="xfails_file", type=str,
+                              required=False, metavar="<path>",
+                              help="Path to a YAML file with a list of Tempest"
+                                   " tests that are expected to fail",
+                              release="0.6.0")
     @cliutils.args("--no-use", action="store_false", dest="do_use",
-                   help="Don't set the task as default for future operations")
+                   help="Not to set the task as default for future operations")
     @cliutils.args("--system-wide", dest="system_wide",
-                   help="Don't create a virtual env when installing Tempest; "
+                   help="Not to create a virtual env when installing Tempest; "
                         "use the local env instead of the Tempest virtual env "
                         "when running the tests. Note that all Tempest "
                         "requirements have to be already installed in "
@@ -79,8 +94,8 @@ class VerifyCommands(object):
                    help="Re-run the tests that failed in the last execution",
                    action="store_true")
     @envutils.with_default_deployment(cli_arg_name="deployment")
-    def start(self, deployment=None, set_name="", regex=None,
-              tests_file=None, tempest_config=None, xfails_file=None,
+    def start(self, deployment=None, set_name="", regex=None, tests_file=None,
+              tests_file_to_skip=None, tempest_config=None, xfails_file=None,
               do_use=True, system_wide=False, concur=0, failing=False):
         """Start verification (run Tempest tests).
 
@@ -88,9 +103,12 @@ class VerifyCommands(object):
         :param set_name: Name of a Tempest test set
         :param regex: Regular expression of test
         :param tests_file: Path to a file with a list of Tempest tests
+                           to run them
+        :param tests_file_to_skip: Path to a file with a list of Tempest tests
+                                   to skip them
         :param tempest_config: User specified Tempest config file location
-        :param xfails_file: Path to a file in YAML format with a list of
-                            Tempest tests that are expected to fail
+        :param xfails_file: Path to a YAML file with a list of Tempest tests
+                            that are expected to fail
         :param do_use: Use new task as default for future operations
         :param system_wide: Whether or not to create a virtual env when
                             installing Tempest; whether or not to use
@@ -101,21 +119,26 @@ class VerifyCommands(object):
         :param failing: Re-run tests that failed during the last execution
         """
 
-        msg = _("Arguments '%s' and '%s' are not compatible. "
+        msg = _("Arguments '%s' and '%s' are incompatible. "
                 "You can use only one of the mentioned arguments.")
-        if regex and set_name:
-            print(msg % ("regex", "set"))
-            return 1
-        if tests_file and set_name:
-            print(msg % ("tests_file", "set"))
-            return 1
-        if tests_file and regex:
-            print(msg % ("tests_file", "regex"))
-            return 1
+        incompatible_args_map = [
+            {"regex": regex, "set": set_name},
+            {"tests-file": tests_file, "set": set_name},
+            {"tests-file": tests_file, "regex": regex},
+            {"tests-file": tests_file, "skip-list": tests_file_to_skip},
+            {"failing": failing, "set": set_name},
+            {"failing": failing, "regex": regex},
+            {"failing": failing, "tests-file": tests_file},
+            {"failing": failing, "skip-list": tests_file_to_skip}
+        ]
+        for args in incompatible_args_map:
+            arg_keys = list(args)
+            if args[arg_keys[0]] and args[arg_keys[1]]:
+                print(msg % (arg_keys[0], arg_keys[1]))
+                return 1
 
         if not (regex or set_name or tests_file or failing):
             set_name = "full"
-
         if set_name and set_name not in AVAILABLE_SETS:
             print(_("Tempest test set '%s' not found "
                     "in available test sets. Available sets are %s.")
@@ -125,13 +148,8 @@ class VerifyCommands(object):
         if tests_file and not os.path.exists(tests_file):
             print(_("File '%s' not found.") % tests_file)
             return 1
-
-        if failing and set_name:
-            print(msg % ("failing", "set"))
-            return 1
-
-        if failing and tests_file:
-            print(msg % ("failing", "tests_file"))
+        if tests_file_to_skip and not os.path.exists(tests_file_to_skip):
+            print(_("File '%s' not found.") % tests_file_to_skip)
             return 1
 
         expected_failures = None
@@ -144,7 +162,8 @@ class VerifyCommands(object):
                 return 1
 
         verification = api.Verification.verify(
-            deployment, set_name=set_name, regex=regex, tests_file=tests_file,
+            deployment, set_name=set_name, regex=regex,
+            tests_file=tests_file, tests_file_to_skip=tests_file_to_skip,
             tempest_config=tempest_config, expected_failures=expected_failures,
             system_wide=system_wide, concur=concur, failing=failing)
 
@@ -166,7 +185,7 @@ class VerifyCommands(object):
                         "Note, Tempest log file needs to be in subunit format")
     @cliutils.args("--no-use", action="store_false", dest="do_use",
                    required=False,
-                   help="Don't set new task as default for future operations")
+                   help="Not to set new task as default for future operations")
     @cliutils.alias("import")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def import_results(self, deployment=None, set_name="", log_file=None,
@@ -387,20 +406,36 @@ class VerifyCommands(object):
     @cliutils.args("--tempest-config", dest="tempest_config", type=str,
                    required=False, metavar="<path>",
                    help="User-specified Tempest config file location")
+    @cliutils.args("--add-options", dest="extra_conf_path", type=str,
+                   required=False, metavar="<path>",
+                   help="Path to a file with additional options "
+                        "to extend/update Tempest config file")
     @cliutils.args("--override", dest="override",
                    help="Override existing Tempest config file",
                    required=False, action="store_true")
     @envutils.with_default_deployment(cli_arg_name="deployment")
-    def genconfig(self, deployment=None, tempest_config=None, override=False):
+    def genconfig(self, deployment=None, tempest_config=None,
+                  extra_conf_path=None, override=False):
         """Generate Tempest configuration file.
 
         :param deployment: UUID or name of a deployment
         :param tempest_config: User-specified Tempest config file location
+        :param extra_conf_path: Path to a file with additional options
+                                to extend/update Tempest config file
         :param override: Whether or not to override existing Tempest
                          config file
         """
+        extra_conf = None
+        if extra_conf_path:
+            if os.path.exists(extra_conf_path):
+                extra_conf = configparser.ConfigParser()
+                extra_conf.read(os.path.abspath(extra_conf_path))
+            else:
+                print(_("File '%s' not found.") % extra_conf_path)
+                return 1
+
         api.Verification.configure_tempest(deployment, tempest_config,
-                                           override)
+                                           extra_conf, override)
 
     @cliutils.args("--deployment", dest="deployment", type=str,
                    metavar="<uuid>", required=False,
@@ -411,8 +446,9 @@ class VerifyCommands(object):
                    help="Commit ID or tag to checkout before Tempest "
                         "installation")
     @cliutils.args("--system-wide", dest="system_wide",
-                   help="Don't create a virtual env for Tempest. Note "
-                        "that all Tempest requirements have to be already "
+                   help="Not to install Tempest package and not to create "
+                        "a virtual env for Tempest. Note that Tempest package "
+                        "and all Tempest requirements have to be already "
                         "installed in the local env!",
                    required=False, action="store_true")
     @envutils.with_default_deployment(cli_arg_name="deployment")
@@ -424,7 +460,8 @@ class VerifyCommands(object):
         :param source: Path/URL to repo to clone Tempest from
         :param version: Commit ID or tag to checkout before Tempest
                         installation
-        :param system_wide: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to install Tempest package and
+                            create a Tempest virtual env
         """
         api.Verification.install_tempest(deployment, source,
                                          version, system_wide)
@@ -449,8 +486,9 @@ class VerifyCommands(object):
                    help="Commit ID or tag to checkout before Tempest "
                         "installation")
     @cliutils.args("--system-wide", dest="system_wide",
-                   help="Don't create a virtual env for Tempest. Note "
-                        "that all Tempest requirements have to be already "
+                   help="Not to install Tempest package and not to create "
+                        "a virtual env for Tempest. Note that Tempest package "
+                        "and all Tempest requirements have to be already "
                         "installed in the local env!",
                    required=False, action="store_true")
     @envutils.with_default_deployment(cli_arg_name="deployment")
@@ -462,7 +500,8 @@ class VerifyCommands(object):
         :param source: Path/URL to repo to clone Tempest from
         :param version: Commit ID or tag to checkout before Tempest
                         installation
-        :param system_wide: Whether or not to create a Tempest virtual env
+        :param system_wide: Whether or not to install Tempest package and
+                            create a Tempest virtual env
         """
         api.Verification.reinstall_tempest(deployment, source,
                                            version, system_wide)
@@ -495,19 +534,62 @@ class VerifyCommands(object):
         api.Verification.install_tempest_plugin(deployment, source,
                                                 version, system_wide)
 
+    @cliutils.args("--deployment", type=str, dest="deployment",
+                   required=False, help="UUID or name of a deployment")
+    @cliutils.args("--system-wide", dest="system_wide",
+                   help="List all plugins installed in the local env, "
+                        "not in Tempest virtual env",
+                   required=False, action="store_true")
+    @envutils.with_default_deployment(cli_arg_name="deployment")
+    def listplugins(self, deployment=None, system_wide=False):
+        """List all installed Tempest plugins.
+
+        :param deployment: UUID or name of a deployment
+        :param system_wide: List all plugins installed in the local env or
+                            in Tempest virtual env
+        """
+        print(api.Verification.list_tempest_plugins(deployment, system_wide))
+
+    @cliutils.args("--deployment", type=str, dest="deployment",
+                   required=False, help="UUID or name of a deployment")
+    @cliutils.args("--repo-name", type=str, dest="repo_name",
+                   required=True, help="Plugin repo name")
+    @cliutils.args("--system-wide", dest="system_wide",
+                   help="Uninstall plugin from the local env, "
+                        "not from Tempest virtual env",
+                   required=False, action="store_true")
+    @envutils.with_default_deployment(cli_arg_name="deployment")
+    def uninstallplugin(self, deployment=None, repo_name=None,
+                        system_wide=False):
+        """Uninstall Tempest plugin.
+
+        :param deployment: UUID or name of a deployment
+        :param repo_name: Plugin repo name
+        :param system_wide: Uninstall plugin from Tempest virtual env or
+                            from the local env
+        """
+        api.Verification.uninstall_tempest_plugin(deployment,
+                                                  repo_name, system_wide)
+
     @cliutils.args("--deployment", dest="deployment", type=str, required=False,
                    metavar="<uuid>", help="UUID or name of a deployment")
     @cliutils.args("--pattern", dest="pattern", type=str,
                    required=False, metavar="<pattern>",
                    help="Test name pattern which can be used to match")
+    @cliutils.args("--system-wide", dest="system_wide",
+                   help="Discover tests for system-wide Tempest installation",
+                   required=False, action="store_true")
     @envutils.with_default_deployment(cli_arg_name="deployment")
-    def discover(self, deployment=None, pattern=""):
+    def discover(self, deployment=None, pattern="", system_wide=False):
         """Show a list of discovered tests.
 
         :param deployment: UUID or name of a deployment
         :param pattern: Test name pattern which can be used to match
+        :param system_wide: Discover tests for system-wide or venv
+                            Tempest installation
         """
-        discovered_tests = api.Verification.discover_tests(deployment, pattern)
+        discovered_tests = api.Verification.discover_tests(deployment, pattern,
+                                                           system_wide)
         p_str = (_(" matching pattern '%s'") % pattern) if pattern else ""
         if discovered_tests:
             print(_("Discovered tests%s:\n") % p_str)
@@ -521,7 +603,7 @@ class VerifyCommands(object):
                    help="UUID or name of a deployment.")
     @envutils.with_default_deployment(cli_arg_name="deployment")
     def showconfig(self, deployment=None):
-        """Show configuration file of Tempest.
+        """Show Tempest configuration file.
 
         :param deployment: UUID or name of a deployment
         """
