@@ -24,10 +24,12 @@ from rally.plugins.openstack.scenarios.ec2 import utils as ec2_utils
 from rally.plugins.openstack.scenarios.heat import utils as heat_utils
 from rally.plugins.openstack.scenarios.ironic import utils as ironic_utils
 from rally.plugins.openstack.scenarios.manila import utils as manila_utils
+from rally.plugins.openstack.scenarios.monasca import utils as monasca_utils
 from rally.plugins.openstack.scenarios.murano import utils as murano_utils
 from rally.plugins.openstack.scenarios.nova import utils as nova_utils
 from rally.plugins.openstack.scenarios.sahara import utils as sahara_utils
 from rally.plugins.openstack.scenarios.vm import utils as vm_utils
+from rally.plugins.openstack.scenarios.watcher import utils as watcher_utils
 from rally.plugins.openstack.wrappers import glance as glance_utils
 from rally.verification.tempest import config as tempest_conf
 
@@ -44,10 +46,12 @@ def list_opts():
                          heat_utils.HEAT_BENCHMARK_OPTS,
                          ironic_utils.IRONIC_BENCHMARK_OPTS,
                          manila_utils.MANILA_BENCHMARK_OPTS,
+                         monasca_utils.MONASCA_BENCHMARK_OPTS,
                          murano_utils.MURANO_BENCHMARK_OPTS,
                          nova_utils.NOVA_BENCHMARK_OPTS,
                          sahara_utils.SAHARA_BENCHMARK_OPTS,
-                         vm_utils.VM_BENCHMARK_OPTS)),
+                         vm_utils.VM_BENCHMARK_OPTS,
+                         watcher_utils.WATCHER_BENCHMARK_OPTS)),
         ("tempest",
          itertools.chain(tempest_conf.TEMPEST_OPTS)),
         ("roles_context", itertools.chain(roles.ROLES_CONTEXT_OPTS)),
