@@ -142,46 +142,25 @@ class OSClient(plugin.Plugin):
             raise exceptions.RallyException(_(
                 "Setting service type is not supported."))
 
-    def keystone(self, *args, **kwargs):
-        """Make a call to keystone client."""
-        keystone = OSClient.get("keystone")(self.credential, self.api_info,
-                                            self.cache)
-        return keystone(*args, **kwargs)
+    @property
+    def keystone(self):
+        return OSClient.get("keystone")(self.credential, self.api_info,
+                                        self.cache)
 
-    def _get_session(self, auth=None, endpoint=None):
-        from keystoneclient.auth import token_endpoint
-        from keystoneclient import session as ks_session
-
-        if auth is None:
-            endpoint = endpoint or self._get_endpoint()
-            kc = self.keystone()
-            auth = token_endpoint.Token(endpoint, kc.auth_token)
-        verify = self.credential.cacert or not self.credential.insecure
-        return ks_session.Session(
-            auth=auth, verify=verify,
-            timeout=CONF.openstack_client_http_timeout)
-
-    def _get_keystoneauth_session(self):
-        from keystoneauth1 import loading
-        from keystoneauth1 import session
-        loader = loading.get_plugin_loader("password")
-        plugin = loader.load_from_options(
-            auth_url=self.credential.auth_url,
-            username=self.credential.username,
-            password=self.credential.password,
-            user_domain_name=self.credential.user_domain_name,
-            project_name=self.credential.tenant_name,
-            project_domain_name=self.credential.project_domain_name)
-        sess = session.Session(auth=plugin, verify=(
-            not self.credential.insecure))
-        return sess
+    def _get_session(self, auth_url=None, version=None):
+        import warnings
+        warnings.warn(
+            "Method `rally.osclient.OSClient._get_session` is deprecated since"
+            " Rally 0.6.0. Use "
+            "`rally.osclient.OSClient.keystone.get_session` instead.")
+        return self.keystone.get_session(version)
 
     def _get_endpoint(self, service_type=None):
-        kc = self.keystone()
-        api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+        kw = {"service_type": self.choose_service_type(service_type),
+              "region_name": self.credential.region_name}
+        if self.credential.endpoint_type:
+            kw["interface"] = self.credential.endpoint_type
+        api_url = self.keystone.service_catalog.url_for(**kw)
         return api_url
 
     def _get_auth_info(self, user_key="username",
@@ -192,6 +171,7 @@ class OSClient(plugin.Plugin):
                        user_domain_name_key="user_domain_name",
                        project_domain_name_key="project_domain_name",
                        cacert_key="cacert",
+                       endpoint_type="endpoint_type",
                        ):
         kw = {
             user_key: self.credential.username,
@@ -211,7 +191,8 @@ class OSClient(plugin.Plugin):
             kw.update({
                 project_domain_name_key:
                 self.credential.project_domain_name or "Default"})
-
+        if self.credential.endpoint_type:
+            kw[endpoint_type] = self.credential.endpoint_type
         return kw
 
     @abc.abstractmethod
@@ -235,39 +216,67 @@ class OSClient(plugin.Plugin):
 @configure("keystone", supported_versions=("2", "3"))
 class Keystone(OSClient):
 
-    def keystone(self, *args, **kwargs):
+    @property
+    def keystone(self):
         raise exceptions.RallyException(_("Method 'keystone' is restricted "
                                           "for keystoneclient. :)"))
 
-    def _create_keystone_client(self, args, version=None):
-        from keystoneclient.auth import identity
-        from keystoneclient import client
-        auth_arg_list = [
-            "username", "project_name", "tenant_name", "auth_url",
-            "password",
-        ]
-        # NOTE(bigjools): If forcing a v2.0 URL then you cannot specify
-        # domain-related info, or the service discovery will fail.
-        if "v2.0" not in args["auth_url"] and version != "2":
-            auth_arg_list.extend(
-                ["user_domain_name", "domain_name", "project_domain_name"])
-        auth_args = {key: args.get(key) for key in auth_arg_list}
-        auth = identity.Password(**auth_args)
-        session = self._get_session(auth=auth)
-        args["session"] = session
-        # NOTE(bigjools): When using sessions, keystoneclient no longer
-        # does any pre-auth and calling client.authenticate() with
-        # sessions is deprecated (it's still possible to call it but if
-        # endpoint is defined it'll crash). We're forcing that pre-auth
-        # here because the use of the service_catalog depends on doing
-        # this. Also note that while the API has got the
-        # endpoints.list() equivalent, there is no service_type in that
-        # list which is why we need to ensure service_catalog is still
-        # present.
-        auth_ref = auth.get_access(session)
-        ks = client.Client(version=version, **args)
-        ks.auth_ref = auth_ref
-        return ks
+    @property
+    def service_catalog(self):
+        return self.auth_ref.service_catalog
+
+    @property
+    def auth_ref(self):
+        if "keystone_auth_ref" not in self.cache:
+            sess, plugin = self.get_session()
+            self.cache["keystone_auth_ref"] = plugin.get_access(sess)
+        return self.cache["keystone_auth_ref"]
+
+    def get_session(self, version=None):
+        key = "keystone_session_and_plugin_%s" % version
+        if key not in self.cache:
+            from keystoneauth1 import discover
+            from keystoneauth1 import identity
+            from keystoneauth1 import session
+
+            version = self.choose_version(version)
+            auth_url = self.credential.auth_url
+            if version is not None:
+                auth_url = self._remove_url_version()
+
+            password_args = {
+                "auth_url": auth_url,
+                "username": self.credential.username,
+                "password": self.credential.password,
+                "tenant_name": self.credential.tenant_name
+            }
+
+            if version is None:
+                # NOTE(rvasilets): If version not specified than we discover
+                # available version with the smallest number. To be able to
+                # discover versions we need session
+                temp_session = session.Session(
+                    verify=(self.credential.cacert or
+                            not self.credential.insecure),
+                    timeout=CONF.openstack_client_http_timeout)
+                version = str(discover.Discover(
+                    temp_session,
+                    password_args["auth_url"]).version_data()[0]["version"][0])
+
+            if "v2.0" not in password_args["auth_url"] and (
+                    version != "2"):
+                password_args.update({
+                    "user_domain_name": self.credential.user_domain_name,
+                    "domain_name": self.credential.domain_name,
+                    "project_domain_name": self.credential.project_domain_name,
+                })
+            identity_plugin = identity.Password(**password_args)
+            sess = session.Session(
+                auth=identity_plugin, verify=(
+                    self.credential.cacert or not self.credential.insecure),
+                timeout=CONF.openstack_client_http_timeout)
+            self.cache[key] = (sess, identity_plugin)
+        return self.cache[key]
 
     def _remove_url_version(self):
         """Remove any version from the auth_url.
@@ -291,20 +300,27 @@ class Keystone(OSClient):
         If this object was constructed with a version in the api_info
         then that will be used unless the version parameter is passed.
         """
+        import keystoneclient
+        from keystoneclient import client
+
         # Use the version in the api_info if provided, otherwise fall
         # back to the passed version (which may be None, in which case
         # keystoneclient chooses).
         version = self.choose_version(version)
-        new_kw = {
-            "timeout": CONF.openstack_client_http_timeout,
-            "insecure": self.credential.insecure,
-            "cacert": self.credential.cacert
-        }
-        kw = self.credential.to_dict()
-        kw.update(new_kw)
-        if version is not None:
-            kw["auth_url"] = self._remove_url_version()
-        return self._create_keystone_client(kw, version=version)
+
+        sess = self.get_session(version=version)[0]
+
+        kw = {"version": version, "session": sess,
+              "timeout": CONF.openstack_client_http_timeout}
+        if keystoneclient.__version__[0] == "1":
+            # NOTE(andreykurilin): let's leave this hack for envs which uses
+            #  old(<2.0.0) keystoneclient version. Upstream fix:
+            #  https://github.com/openstack/python-keystoneclient/commit/d9031c252848d89270a543b67109a46f9c505c86
+            from keystoneauth1 import plugin
+            kw["auth_url"] = sess.get_endpoint(interface=plugin.AUTH_INTERFACE)
+        if self.credential.endpoint_type:
+            kw["endpoint_type"] = self.credential.endpoint_type
+        return client.Client(**kw)
 
 
 @configure("nova", default_version="2", default_service_type="compute")
@@ -323,18 +339,14 @@ class Nova(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return nova client."""
         from novaclient import client as nova
-        kc = self.keystone()
-        compute_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+
         client = nova.Client(self.choose_version(version),
-                             auth_token=kc.auth_token,
+                             auth_token=self.keystone.auth_ref.auth_token,
                              http_log_debug=logging.is_debug(),
                              timeout=CONF.openstack_client_http_timeout,
                              insecure=self.credential.insecure,
                              **self._get_auth_info(password_key="api_key"))
-        client.set_management_url(compute_api_url)
+        client.set_management_url(self._get_endpoint(service_type))
         return client
 
 
@@ -344,14 +356,10 @@ class Neutron(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return neutron client."""
         from neutronclient.neutron import client as neutron
-        kc = self.keystone()
-        network_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+
         client = neutron.Client(self.choose_version(version),
-                                token=kc.auth_token,
-                                endpoint_url=network_api_url,
+                                token=self.keystone.auth_ref.auth_token,
+                                endpoint_url=self._get_endpoint(service_type),
                                 timeout=CONF.openstack_client_http_timeout,
                                 insecure=self.credential.insecure,
                                 **self._get_auth_info(
@@ -366,14 +374,10 @@ class Glance(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return glance client."""
         import glanceclient as glance
-        kc = self.keystone()
-        image_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+
         client = glance.Client(self.choose_version(version),
-                               endpoint=image_api_url,
-                               token=kc.auth_token,
+                               endpoint=self._get_endpoint(service_type),
+                               token=self.keystone.auth_ref.auth_token,
                                timeout=CONF.openstack_client_http_timeout,
                                insecure=self.credential.insecure,
                                cacert=self.credential.cacert)
@@ -386,14 +390,10 @@ class Heat(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return heat client."""
         from heatclient import client as heat
-        kc = self.keystone()
-        orchestration_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+
         client = heat.Client(self.choose_version(version),
-                             endpoint=orchestration_api_url,
-                             token=kc.auth_token,
+                             endpoint=self._get_endpoint(service_type),
+                             token=self.keystone.auth_ref.auth_token,
                              timeout=CONF.openstack_client_http_timeout,
                              insecure=self.credential.insecure,
                              **self._get_auth_info(project_name_key=None,
@@ -407,18 +407,14 @@ class Cinder(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return cinder client."""
         from cinderclient import client as cinder
+
         client = cinder.Client(self.choose_version(version),
                                http_log_debug=logging.is_debug(),
                                timeout=CONF.openstack_client_http_timeout,
                                insecure=self.credential.insecure,
                                **self._get_auth_info(password_key="api_key"))
-        kc = self.keystone()
-        volume_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
-        client.client.management_url = volume_api_url
-        client.client.auth_token = kc.auth_token
+        client.client.management_url = self._get_endpoint(service_type)
+        client.client.auth_token = self.keystone.auth_ref.auth_token
         return client
 
 
@@ -436,12 +432,8 @@ class Manila(OSClient):
             insecure=self.credential.insecure,
             **self._get_auth_info(password_key="api_key",
                                   project_name_key="project_name"))
-        kc = self.keystone()
-        manila_client.client.management_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
-        manila_client.client.auth_token = kc.auth_token
+        manila_client.client.management_url = self._get_endpoint(service_type)
+        manila_client.client.auth_token = self.keystone.auth_ref.auth_token
         return manila_client
 
 
@@ -451,23 +443,15 @@ class Ceilometer(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return ceilometer client."""
         from ceilometerclient import client as ceilometer
-        kc = self.keystone()
-        metering_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
-        auth_token = kc.auth_token
-        if not hasattr(auth_token, "__call__"):
-            # python-ceilometerclient requires auth_token to be a callable
-            auth_token = lambda: kc.auth_token
 
         client = ceilometer.get_client(
             self.choose_version(version),
-            os_endpoint=metering_api_url,
-            token=auth_token,
+            os_endpoint=self._get_endpoint(service_type),
+            token=self.keystone.auth_ref.auth_token,
             timeout=CONF.openstack_client_http_timeout,
             insecure=self.credential.insecure,
-            **self._get_auth_info(project_name_key="tenant_name"))
+            **self._get_auth_info(project_name_key="tenant_name",
+                                  endpoint_type="interface"))
         return client
 
 
@@ -480,8 +464,9 @@ class Gnocchi(OSClient):
         # NOTE(sumantmurke): gnocchiclient requires keystoneauth1 for
         # authenticating and creating a session.
         from gnocchiclient import client as gnocchi
+
         service_type = self.choose_service_type(service_type)
-        sess = self._get_keystoneauth_session()
+        sess = self.keystone.get_session()[0]
         gclient = gnocchi.Client(version=self.choose_version(
             version), session=sess, service_type=service_type)
         return gclient
@@ -494,17 +479,17 @@ class Ironic(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return Ironic client."""
         from ironicclient import client as ironic
-        kc = self.keystone()
-        baremetal_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+
+        auth_token = self.keystone.auth_ref.auth_token
         client = ironic.get_client(self.choose_version(version),
-                                   os_auth_token=kc.auth_token,
-                                   ironic_url=baremetal_api_url,
+                                   os_auth_token=auth_token,
+                                   ironic_url=self._get_endpoint(service_type),
                                    timeout=CONF.openstack_client_http_timeout,
                                    insecure=self.credential.insecure,
-                                   cacert=self.credential.cacert)
+                                   cacert=self.credential.cacert,
+                                   interface=self._get_auth_info().get(
+                                       "endpoint_type")
+                                   )
         return client
 
 
@@ -525,10 +510,10 @@ class Sahara(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return Sahara client."""
         from saharaclient import client as sahara
+
         client = sahara.Client(
             self.choose_version(version),
             service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
             insecure=self.credential.insecure,
             **self._get_auth_info(password_key="api_key",
                                   project_name_key="project_name"))
@@ -546,20 +531,16 @@ class Zaqar(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return Zaqar client."""
         from zaqarclient.queues import client as zaqar
-        kc = self.keystone()
-        messaging_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+        tenant_id = self.keystone.auth_ref.project_id
         conf = {"auth_opts": {"backend": "keystone", "options": {
             "os_username": self.credential.username,
             "os_password": self.credential.password,
             "os_project_name": self.credential.tenant_name,
-            "os_project_id": kc.auth_ref.get("token").get("tenant").get("id"),
+            "os_project_id": tenant_id,
             "os_auth_url": self.credential.auth_url,
             "insecure": self.credential.insecure,
         }}}
-        client = zaqar.Client(url=messaging_api_url,
+        client = zaqar.Client(url=self._get_endpoint(),
                               version=self.choose_version(version),
                               conf=conf)
         return client
@@ -572,16 +553,10 @@ class Murano(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return Murano client."""
         from muranoclient import client as murano
-        kc = self.keystone()
-        murano_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name
-        )
 
         client = murano.Client(self.choose_version(version),
-                               endpoint=murano_url,
-                               token=kc.auth_token)
+                               endpoint=self._get_endpoint(service_type),
+                               token=self.keystone.auth_ref.auth_token)
 
         return client
 
@@ -598,8 +573,12 @@ class Designate(OSClient):
         api_url = self._get_endpoint(service_type)
         api_url += "/v%s" % version
 
-        session = self._get_session(endpoint=api_url)
-        return client.Client(version, session=session)
+        session = self.keystone.get_session()[0]
+        if version == "2":
+            return client.Client(version, session=session,
+                                 endpoint_override=api_url)
+        return client.Client(version, session=session,
+                             endpoint=api_url)
 
 
 @configure("trove", default_version="1.0", supported_versions=["1.0"])
@@ -607,6 +586,7 @@ class Trove(OSClient):
     def create_client(self, version=None):
         """Returns trove client."""
         from troveclient import client as trove
+
         client = trove.Client(self.choose_version(version),
                               region_name=self.credential.region_name,
                               timeout=CONF.openstack_client_http_timeout,
@@ -620,18 +600,12 @@ class Trove(OSClient):
 class Mistral(OSClient):
     def create_client(self, service_type=None):
         """Return Mistral client."""
-        from mistralclient.api import client
-        kc = self.keystone()
+        from mistralclient.api import client as mistral
 
-        mistral_url = kc.service_catalog.url_for(
+        client = mistral.client(
+            mistral_url=self._get_endpoint(service_type),
             service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
-
-        client = client.client(
-            mistral_url=mistral_url,
-            service_type=self.choose_service_type(service_type),
-            auth_token=kc.auth_token)
+            auth_token=self.keystone.auth_ref.auth_token)
         return client
 
 
@@ -640,14 +614,11 @@ class Swift(OSClient):
     def create_client(self, service_type=None):
         """Return swift client."""
         from swiftclient import client as swift
-        kc = self.keystone()
-        object_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
+
+        auth_token = self.keystone.auth_ref.auth_token
         client = swift.Connection(retries=1,
-                                  preauthurl=object_api_url,
-                                  preauthtoken=kc.auth_token,
+                                  preauthurl=self._get_endpoint(service_type),
+                                  preauthtoken=auth_token,
                                   insecure=self.credential.insecure,
                                   cacert=self.credential.cacert,
                                   user=self.credential.username,
@@ -661,19 +632,17 @@ class EC2(OSClient):
     def create_client(self):
         """Return ec2 client."""
         import boto
+
         kc = self.keystone()
+
         if kc.version != "v2.0":
             raise exceptions.RallyException(
                 _("Rally EC2 benchmark currently supports only"
                   "Keystone version 2"))
         ec2_credential = kc.ec2.create(user_id=kc.auth_user_id,
                                        tenant_id=kc.auth_tenant_id)
-        ec2_api_url = kc.service_catalog.url_for(
-            service_type=consts.ServiceType.EC2,
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
         client = boto.connect_ec2_endpoint(
-            url=ec2_api_url,
+            url=self._get_endpoint(),
             aws_access_key_id=ec2_credential.access,
             aws_secret_access_key=ec2_credential.secret,
             is_secure=self.credential.insecure)
@@ -686,16 +655,11 @@ class Monasca(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return monasca client."""
         from monascaclient import client as monasca
-        kc = self.keystone()
-        monitoring_api_url = kc.service_catalog.url_for(
-            service_type=self.choose_service_type(service_type),
-            endpoint_type=self.credential.endpoint_type,
-            region_name=self.credential.region_name)
-        auth_token = kc.auth_token
+
         client = monasca.Client(
             self.choose_version(version),
-            monitoring_api_url,
-            token=auth_token,
+            self._get_endpoint(service_type),
+            token=self.keystone.auth_ref.auth_token,
             timeout=CONF.openstack_client_http_timeout,
             insecure=self.credential.insecure,
             **self._get_auth_info(project_name_key="tenant_name"))
@@ -712,10 +676,10 @@ class Cue(OSClient):
         api_url = self._get_endpoint(service_type)
         api_url += "v%s" % version
 
-        session = self._get_session(endpoint=api_url)
-        endpoint_type = self.credential.endpoint_type,
+        session = self.keystone.get_session()[0]
+        endpoint_type = self.credential.endpoint_type
 
-        return cue.Client(session=session, interface=endpoint_type[0])
+        return cue.Client(session=session, interface=endpoint_type)
 
 
 @configure("senlin", default_version="1", default_service_type="clustering",
@@ -724,13 +688,15 @@ class Senlin(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return senlin client."""
         from senlinclient import client as senlin
+
         return senlin.Client(
             self.choose_version(version),
             **self._get_auth_info(project_name_key="project_name",
-                                  cacert_key="cert"))
+                                  cacert_key="cert",
+                                  endpoint_type="interface"))
 
 
-@configure("magnum", default_version="1",
+@configure("magnum", default_version="1", supported_versions=["1"],
            default_service_type="container-infra",)
 class Magnum(OSClient):
     def create_client(self, version=None, service_type=None):
@@ -738,10 +704,12 @@ class Magnum(OSClient):
         from magnumclient import client as magnum
 
         api_url = self._get_endpoint(service_type)
-        session = self._get_session(endpoint=api_url)
-        endpoint_type = self.credential.endpoint_type,
+        session = self.keystone.get_session()[0]
 
-        return magnum.Client(session=session, interface=endpoint_type[0])
+        return magnum.Client(
+            session=session,
+            interface=self.credential.endpoint_type,
+            magnum_url=api_url)
 
 
 @configure("watcher", default_version="1", default_service_type="infra-optim",
@@ -750,16 +718,16 @@ class Watcher(OSClient):
     def create_client(self, version=None, service_type=None):
         """Return watcher client."""
         from watcherclient import client as watcher_client
-        kc = self.keystone()
         watcher_api_url = self._get_endpoint(
             self.choose_service_type(service_type))
         client = watcher_client.Client(
             self.choose_version(version),
             watcher_api_url,
-            token=kc.auth_token,
+            token=self.keystone.auth_ref.auth_token,
             timeout=CONF.openstack_client_http_timeout,
             insecure=self.credential.insecure,
-            ca_file=self.credential.cacert)
+            ca_file=self.credential.cacert,
+            endpoint_type=self.credential.endpoint_type)
         return client
 
 
@@ -806,9 +774,8 @@ class Clients(object):
         from keystoneclient import exceptions as keystone_exceptions
         try:
             # Ensure that user is admin
-            client = self.keystone()
             if "admin" not in [role.lower() for role in
-                               client.auth_ref.role_names]:
+                               self.keystone.auth_ref.role_names]:
                 raise exceptions.InvalidAdminException(
                     username=self.credential.username)
         except keystone_exceptions.Unauthorized:
@@ -816,7 +783,7 @@ class Clients(object):
         except keystone_exceptions.AuthorizationFailure:
             raise exceptions.HostUnreachableException(
                 url=self.credential.auth_url)
-        return client
+        return self.keystone()
 
     def services(self):
         """Return available services names and types.
@@ -825,8 +792,7 @@ class Clients(object):
         """
         if "services_data" not in self.cache:
             services_data = {}
-            ks = self.keystone()
-            available_services = ks.service_catalog.get_endpoints()
+            available_services = self.keystone.service_catalog.get_endpoints()
             for stype in available_services.keys():
                 if stype in consts.ServiceType:
                     services_data[stype] = consts.ServiceType[stype]
@@ -835,50 +801,3 @@ class Clients(object):
             self.cache["services_data"] = services_data
 
         return self.cache["services_data"]
-
-    @classmethod
-    @logging.log_deprecated("Use rally.osclients.configure decorator instead.",
-                            "0.1.2")
-    def register(cls, client_name):
-        """DEPRECATED!Decorator that adds new OpenStack client dynamically.
-
-        Use rally.osclients.configure decorator instead!
-
-        :param client_name: str name how client will be named in Rally clients
-
-        Decorated class will be added to Clients in runtime, so its sole
-        argument is a Clients instance.
-
-        Decorated function will be added to Clients in runtime, so its sole
-        argument is a Clients instance.
-
-        Example:
-          >>> from rally import osclients
-          >>> @osclients.Clients.register("supernova")
-          ... def another_nova_client(self):
-          ...   from novaclient import client as nova
-          ...   return nova.Client("2", auth_token=self.keystone().auth_token,
-          ...                      **self._get_auth_info(password_key="key"))
-          ...
-          >>> clients = osclients.Clients.create_from_env()
-          >>> clients.supernova().services.list()[:2]
-          [<Service: nova-conductor>, <Service: nova-cert>]
-        """
-        def wrap(client_func):
-            try:
-                OSClient.get(client_name)
-            except exceptions.PluginNotFound:
-                # everything is ok
-                pass
-            else:
-                raise ValueError(
-                    _("Can not register client: name already exists: %s")
-                    % client_name)
-
-            @configure(client_name)
-            class NewClient(OSClient):
-                create_client = client_func
-
-            return NewClient
-
-        return wrap
