@@ -20,14 +20,11 @@ import time
 
 from six.moves import queue as Queue
 
-from rally.common import logging
 from rally.common import utils
 from rally import consts
 from rally.task import runner
 from rally.task import utils as butils
 
-LOG = logging.getLogger(__name__)
-
 
 def _worker_process(queue, iteration_gen, timeout, concurrency, times,
                     context, cls, method_name, args, aborted, info):
@@ -71,24 +68,23 @@ def _worker_process(queue, iteration_gen, timeout, concurrency, times,
 
     iteration = next(iteration_gen)
     while iteration < times and not aborted.is_set():
-        scenario_context = runner._get_scenario_context(context)
-        scenario_args = (iteration, cls, method_name, scenario_context, args)
-        worker_args = (queue, scenario_args)
+        scenario_context = runner._get_scenario_context(iteration, context)
+        worker_args = (queue, cls, method_name, scenario_context, args)
 
         thread = threading.Thread(target=runner._worker_thread,
                                   args=worker_args)
 
         thread.start()
         if timeout:
-            timeout_queue.put((thread.ident, time.time() + timeout))
-        pool.append((thread, time.time()))
+            timeout_queue.put((thread, time.time() + timeout))
+        pool.append(thread)
         alive_threads_in_pool += 1
 
         while alive_threads_in_pool == concurrency:
             prev_finished_threads_in_pool = finished_threads_in_pool
             finished_threads_in_pool = 0
             for t in pool:
-                if not t[0].isAlive():
+                if not t.isAlive():
                     finished_threads_in_pool += 1
 
             alive_threads_in_pool -= finished_threads_in_pool
@@ -98,8 +94,8 @@ def _worker_process(queue, iteration_gen, timeout, concurrency, times,
                 # NOTE(boris-42): cleanup pool array. This is required because
                 # in other case array length will be equal to times which
                 # is unlimited big
-                while pool and not pool[0][0].isAlive():
-                    pool.popleft()[0].join()
+                while pool and not pool[0].isAlive():
+                    pool.popleft().join()
                     finished_threads_in_pool -= 1
                 break
 
@@ -109,7 +105,7 @@ def _worker_process(queue, iteration_gen, timeout, concurrency, times,
 
     # Wait until all threads are done
     while pool:
-        pool.popleft()[0].join()
+        pool.popleft().join()
 
     if timeout:
         timeout_queue.put((None, None,))
@@ -147,7 +143,6 @@ class ConstantScenarioRunner(runner.ScenarioRunner):
             },
             "timeout": {
                 "type": "number",
-                "minimum": 1
             },
             "max_cpu_count": {
                 "type": "integer",
@@ -210,6 +205,18 @@ class ConstantScenarioRunner(runner.ScenarioRunner):
         self._join_processes(process_pool, result_queue)
 
 
+def _run_scenario_once_with_unpack_args(args):
+    # NOTE(andreykurilin): `pool.imap` is used in
+    #     ConstantForDurationScenarioRunner. It does not want to work with
+    #     instance-methods, class-methods and static-methods. Also, it can't
+    #     transmit positional or keyword arguments to destination function.
+    #     While original `rally.task.runner._run_scenario_once` accepts
+    #     multiple arguments instead of one big tuple with all arguments, we
+    #     need to hardcode unpacking here(all other runners are able to
+    #     transmit arguments in proper way).
+    return runner._run_scenario_once(*args)
+
+
 @runner.configure(name="constant_for_duration")
 class ConstantForDurationScenarioRunner(runner.ScenarioRunner):
     """Creates constant load executing a scenario for an interval of time.
@@ -253,7 +260,7 @@ class ConstantForDurationScenarioRunner(runner.ScenarioRunner):
         def _scenario_args(i):
             if aborted.is_set():
                 raise StopIteration()
-            return (i, cls, method, runner._get_scenario_context(ctx), args)
+            return (cls, method, runner._get_scenario_context(i, ctx), args)
         return _scenario_args
 
     def _run_scenario(self, cls, method, context, args):
@@ -272,12 +279,14 @@ class ConstantForDurationScenarioRunner(runner.ScenarioRunner):
         concurrency = self.config.get("concurrency", 1)
         duration = self.config.get("duration")
 
+        # FIXME(andreykurilin): unify `_worker_process`, use it here and remove
+        #     usage of `multiprocessing.Pool`(usage of separate process for
+        #     each concurrent iteration is redundant).
         pool = multiprocessing.Pool(concurrency)
 
         run_args = butils.infinite_run_args_generator(
-            self._iter_scenario_args(cls, method, context, args,
-                                     self.aborted))
-        iter_result = pool.imap(runner._run_scenario_once, run_args)
+            self._iter_scenario_args(cls, method, context, args, self.aborted))
+        iter_result = pool.imap(_run_scenario_once_with_unpack_args, run_args)
 
         start = time.time()
         while True:
