@@ -18,11 +18,12 @@ import multiprocessing
 import threading
 import time
 
-from rally.benchmark.runners import base
-from rally.common import log as logging
+from six.moves import queue as Queue
+
+from rally.common import logging
 from rally.common import utils
 from rally import consts
-
+from rally.task import runner
 
 LOG = logging.getLogger(__name__)
 
@@ -52,25 +53,36 @@ def _worker_process(queue, iteration_gen, timeout, rps, times,
     """
 
     pool = collections.deque()
-    start = time.time()
     sleep = 1.0 / rps
 
-    base._log_worker_info(times=times, rps=rps, timeout=timeout,
-                          cls=cls, method_name=method_name, args=args)
+    runner._log_worker_info(times=times, rps=rps, timeout=timeout,
+                            cls=cls, method_name=method_name, args=args)
 
     time.sleep(
         (sleep * info["processes_counter"]) / info["processes_to_start"])
 
+    start = time.time()
+    timeout_queue = Queue.Queue()
+
+    if timeout:
+        collector_thr_by_timeout = threading.Thread(
+            target=utils.timeout_thread,
+            args=(timeout_queue, )
+        )
+        collector_thr_by_timeout.start()
+
     i = 0
     while i < times and not aborted.is_set():
-        scenario_context = base._get_scenario_context(context)
-        scenario_args = (next(iteration_gen), cls, method_name,
-                         scenario_context, args)
-        worker_args = (queue, scenario_args)
-        thread = threading.Thread(target=base._worker_thread,
+        scenario_context = runner._get_scenario_context(next(iteration_gen),
+                                                        context)
+        worker_args = (queue, cls, method_name, scenario_context, args)
+        thread = threading.Thread(target=runner._worker_thread,
                                   args=worker_args)
+
         i += 1
         thread.start()
+        if timeout:
+            timeout_queue.put((thread, time.time() + timeout))
         pool.append(thread)
 
         time_gap = time.time() - start
@@ -90,11 +102,15 @@ def _worker_process(queue, iteration_gen, timeout, rps, times,
                 time.sleep(0.001)
 
     while pool:
-        thr = pool.popleft()
-        thr.join()
+        pool.popleft().join()
+
+    if timeout:
+        timeout_queue.put((None, None,))
+        collector_thr_by_timeout.join()
 
 
-class RPSScenarioRunner(base.ScenarioRunner):
+@runner.configure(name="rps")
+class RPSScenarioRunner(runner.ScenarioRunner):
     """Scenario runner that does the job with specified frequency.
 
     Every single benchmark scenario iteration is executed with specified
@@ -106,8 +122,6 @@ class RPSScenarioRunner(base.ScenarioRunner):
     a certain cloud can handle.
     """
 
-    __execution_type__ = consts.RunnerType.RPS
-
     CONFIG_SCHEMA = {
         "type": "object",
         "$schema": consts.JSON_SCHEMA,
@@ -136,6 +150,7 @@ class RPSScenarioRunner(base.ScenarioRunner):
                 "minimum": 1
             }
         },
+        "required": ["type", "times", "rps"],
         "additionalProperties": False
     }
 
@@ -171,8 +186,7 @@ class RPSScenarioRunner(base.ScenarioRunner):
 
         # Determine concurrency per worker
         concurrency_per_worker, concurrency_overhead = divmod(
-                       self.config.get("max_concurrency", times),
-                       processes_to_start)
+            self.config.get("max_concurrency", times), processes_to_start)
 
         self._log_debug_info(times=times, timeout=timeout,
                              max_cpu_used=max_cpu_used,
