@@ -74,6 +74,41 @@ class HeatStack(base.ResourceManager):
         return self.raw_resource.stack_name
 
 
+# SENLIN
+
+_senlin_order = get_order(150)
+
+
+@base.resource(service=None, resource=None, admin_required=True)
+class SenlinMixin(base.ResourceManager):
+
+    def id(self):
+        return self.raw_resource["id"]
+
+    def _manager(self):
+        client = self._admin_required and self.admin or self.user
+        return getattr(client, self._service)()
+
+    def list(self):
+        return getattr(self._manager(), self._resource)()
+
+    def delete(self):
+        # make singular form of resource name from plural form
+        res_name = self._resource[:-1]
+        return getattr(self._manager(), "delete_%s" % res_name)(self.id())
+
+
+@base.resource("senlin", "clusters", order=next(_senlin_order))
+class SenlinCluster(SenlinMixin):
+    """Resource class for Senlin Cluster."""
+
+
+@base.resource("senlin", "profiles", order=next(_senlin_order),
+               admin_required=False, tenant_resource=True)
+class SenlinProfile(SenlinMixin):
+    """Resource class for Senlin Profile."""
+
+
 # NOVA
 
 _nova_order = get_order(200)
@@ -722,13 +757,17 @@ class FuelEnvironment(base.ResourceManager):
 
 # WATCHER
 
-@base.resource("watcher", "audit_template", order=1500,
-               admin_required=True, tenant_resource=True)
-class WatcherTemplate(SynchronizedDeletion, base.ResourceManager):
+_watcher_order = get_order(1500)
+
+
+class WatcherMixin(SynchronizedDeletion, base.ResourceManager):
 
     def id(self):
         return self.raw_resource.uuid
 
+    def list(self):
+        return self._manager().list(limit=0)
+
     def is_deleted(self):
         from watcherclient.common.apiclient import exceptions
         try:
@@ -737,8 +776,27 @@ class WatcherTemplate(SynchronizedDeletion, base.ResourceManager):
         except exceptions.NotFound:
             return True
 
-    def list(self):
-        return self._manager().list(limit=0)
+
+@base.resource("watcher", "audit_template", order=next(_watcher_order),
+               admin_required=True, perform_for_admin_only=True)
+class WatcherTemplate(WatcherMixin):
+    pass
+
+
+@base.resource("watcher", "action_plan", order=next(_watcher_order),
+               admin_required=True, perform_for_admin_only=True)
+class WatcherActionPlan(WatcherMixin):
+
+    def name(self):
+        return self.raw_resource.uuid
+
+
+@base.resource("watcher", "audit", order=next(_watcher_order),
+               admin_required=True, perform_for_admin_only=True)
+class WatcherAudit(WatcherMixin):
+
+    def name(self):
+        return self.raw_resource.uuid
 
 
 # KEYSTONE
