@@ -13,16 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from rally.common import logging
 from rally import consts
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.nova import utils
 from rally.task import validation
 
 
-LOG = logging.getLogger(__name__)
-
-
 class NovaAggregates(utils.NovaScenario):
     """Benchmark scenarios for Nova aggregates."""
 
