@@ -24,8 +24,8 @@ from rally.common import streaming_algorithms as streaming
 from rally.task.processing import utils
 
 
+@plugin.base()
 @six.add_metaclass(abc.ABCMeta)
-@plugin.configure(name="base_output_chart")
 class Chart(plugin.Plugin):
     """Base class for charts.
 
@@ -431,8 +431,8 @@ class OutputStackedAreaChart(OutputChart):
             complete={"title": "Complete data as stacked area",
                       "description": "Data is shown as stacked area, as-is",
                       "chart_plugin": "StackedArea",
-                      "data": [["foo", [0, 5], [1, 42], [2, 15], [3, 7]],
-                               ["bar", [0, 2], [1, 1.3], [2, 5], [3, 9]]],
+                      "data": [["foo", [[0, 5], [1, 42], [2, 15], [3, 7]]],
+                               ["bar", [[0, 2], [1, 1.3], [2, 5], [3, 9]]]],
                       "label": "Y-axis label text",
                       "axis_label": "X-axis label text"})
     """
@@ -472,8 +472,8 @@ class OutputLinesChart(OutputStackedAreaChart):
             complete={"title": "Complete data as stacked area",
                       "description": "Data is shown as stacked area, as-is",
                       "chart_plugin": "Lines",
-                      "data": [["foo", [0, 5], [1, 42], [2, 15], [3, 7]],
-                               ["bar", [0, 2], [1, 1.3], [2, 5], [3, 9]]],
+                      "data": [["foo", [[0, 5], [1, 42], [2, 15], [3, 7]]],
+                               ["bar", [[0, 2], [1, 1.3], [2, 5], [3, 9]]]],
                       "label": "Y-axis label text",
                       "axis_label": "X-axis label text"})
     """
@@ -575,8 +575,12 @@ class OutputStatsTable(OutputTable):
 
 _OUTPUT_SCHEMA = {
     "key_types": {
-        "title": str, "description": str, "chart_plugin": str,
-        "data": (list, dict), "label": str, "axis_label": str},
+        "title": six.string_types,
+        "description": six.string_types,
+        "chart_plugin": six.string_types,
+        "data": (list, dict),
+        "label": six.string_types,
+        "axis_label": six.string_types},
     "required": ["title", "chart_plugin", "data"]}
 
 
