@@ -21,6 +21,7 @@ import six
 
 from rally.common import objects
 from rally.common.plugin import plugin
+from rally.common import version
 from rally.task.processing import charts
 from rally.ui import utils as ui_utils
 
@@ -38,7 +39,7 @@ def _process_scenario(data, pos):
     output_errors = []
     additive_output_charts = []
     complete_output = []
-    for idx, itr in enumerate(data["iterations"]):
+    for idx, itr in enumerate(data["iterations"], 1):
         if itr["error"]:
             typ, msg, trace = itr["error"]
             errors.append({"iteration": idx,
@@ -150,7 +151,9 @@ def plot(tasks_results, include_libs=False):
     extended_results = _extend_results(tasks_results)
     template = ui_utils.get_template("task/report.html")
     source, data = _process_tasks(extended_results)
-    return template.render(source=json.dumps(source), data=json.dumps(data),
+    return template.render(version=version.version_string(),
+                           source=json.dumps(source),
+                           data=json.dumps(data),
                            include_libs=include_libs)
 
 
@@ -159,7 +162,8 @@ def trends(tasks_results):
     for i, scenario in enumerate(_extend_results(tasks_results), 1):
         trends.add_result(scenario)
     template = ui_utils.get_template("task/trends.html")
-    return template.render(data=json.dumps(trends.get_data()))
+    return template.render(version=version.version_string(),
+                           data=json.dumps(trends.get_data()))
 
 
 class Trends(object):
@@ -233,27 +237,39 @@ class Trends(object):
                                                    "90%ile": [],
                                                    "95%ile": [],
                                                    "max": [],
-                                                   "avg": []}
+                                                   "avg": [],
+                                                   "success": []}
                 self._tasks[key]["data"][k][tgt].append(
                     (self._tasks[key]["seq"], task[k][src]))
 
+            try:
+                success = float(task[k]["Success"].rstrip("%"))
+            except ValueError:
+                # Got "n/a" for some reason
+                success = 0
+            self._tasks[key]["data"][k]["success"].append(
+                (self._tasks[key]["seq"], success))
+
     def get_data(self):
         for key, value in self._tasks.items():
             total = None
             for k, v in value["data"].items():
+                success = [("success", v.pop("success"))]
                 if k == "total":
-                    total = v
+                    total = {"values": v, "success": success}
                 else:
                     self._tasks[key]["atomic"].append(
-                        {"name": k, "values": list(v.items())})
+                        {"name": k, "values": list(v.items()),
+                         "success": success})
             for stat, comp in (("min", charts.streaming.MinComputation()),
                                ("max", charts.streaming.MaxComputation()),
                                ("avg", charts.streaming.MeanComputation())):
-                for k, v in total[stat]:
+                for k, v in total["values"][stat]:
                     if isinstance(v, (float,) + six.integer_types):
                         comp.add(v)
                 self._tasks[key]["stat"][stat] = comp.result()
             del self._tasks[key]["data"]
-            self._tasks[key]["total"] = list(total.items())
+            total["values"] = list(total["values"].items())
+            self._tasks[key]["total"] = total
             self._tasks[key]["single"] = self._tasks[key]["seq"] < 2
         return sorted(self._tasks.values(), key=lambda s: s["name"])
