@@ -13,11 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-
+import inspect
 import random
 
 import six
 
+from rally.common.i18n import _
 from rally.common import logging
 from rally.common.objects import task  # noqa
 from rally.common.plugin import plugin
@@ -33,23 +34,32 @@ LOG = logging.getLogger(__name__)
 
 
 def configure(name=None, namespace="default", context=None):
-    """Make from plain python method task scenario plugin.
+    """Configure scenario by setting proper meta data.
 
-       :param name: Plugin name
-       :param namespace: Plugin namespace
-       :param context: Default task context that is created for this scenario.
-                       If there are custom user specified contexts this one
-                       will be updated by provided contexts.
+    This can also transform plain function into scenario plugin, however
+    this approach is deprecated - now scenarios must be represented by classes
+    based on rally.task.scenario.Scenario.
+
+    :param name: str scenario name
+    :param namespace: str plugin namespace
+    :param context: default task context that is created for this scenario.
+                    If there are custom user specified contexts this one
+                    will be updated by provided contexts.
     """
-    def wrapper(func):
-        plugin.from_func(Scenario)(func)
-        func._meta_init()
+    def wrapper(scen):
+        scen.is_classbased = hasattr(scen, "run") and callable(scen.run)
+        if not scen.is_classbased:
+            plugin.from_func(Scenario)(scen)
+        scen._meta_init()
         if name:
-            func._set_name_and_namespace(name, namespace)
+            if "." not in name.strip("."):
+                msg = (_("Scenario name must include a dot: '%s'") % name)
+                raise exceptions.RallyException(msg)
+            scen._set_name_and_namespace(name, namespace)
         else:
-            func._meta_set("namespace", namespace)
-        func._meta_set("default_context", context or {})
-        return func
+            scen._meta_set("namespace", namespace)
+        scen._meta_set("default_context", context or {})
+        return scen
     return wrapper
 
 
@@ -91,6 +101,7 @@ class ConfigurePluginMeta(type):
                     cls, field._plugin.func_ref.__name__)
 
 
+@plugin.base()
 @six.add_metaclass(ConfigurePluginMeta)
 class Scenario(plugin.Plugin,
                atomic.ActionTimerMixin,
@@ -123,10 +134,45 @@ class Scenario(plugin.Plugin,
                 if not result.is_valid:
                     raise exceptions.InvalidScenarioArgument(result.msg)
 
+    @staticmethod
+    def _validate_scenario_args(scenario, name, config):
+        if scenario.is_classbased:
+            # We need initialize scenario class to access instancemethods
+            scenario = scenario().run
+        args, _varargs, varkwargs, defaults = inspect.getargspec(scenario)
+
+        hint_msg = (" Use `rally plugin show --name %s` to display "
+                    "scenario description." % name)
+
+        # scenario always accepts an instance of scenario cls as a first arg
+        missed_args = args[1:]
+        if defaults:
+            # do not require args with default values
+            missed_args = missed_args[:-len(defaults)]
+        if "args" in config:
+            missed_args = set(missed_args) - set(config["args"])
+        if missed_args:
+            msg = ("Argument(s) '%(args)s' should be specified in task config."
+                   "%(hint)s" % {"args": "', '".join(missed_args),
+                                 "hint": hint_msg})
+            raise exceptions.InvalidArgumentsException(msg)
+
+        if varkwargs is None and "args" in config:
+            redundant_args = set(config["args"]) - set(args[1:])
+            if redundant_args:
+                msg = ("Unexpected argument(s) found ['%(args)s'].%(hint)s" %
+                       {"args": "', '".join(redundant_args),
+                        "hint": hint_msg})
+                raise exceptions.InvalidArgumentsException(msg)
+
     @classmethod
     def validate(cls, name, config, admin=None, users=None, deployment=None):
         """Semantic check of benchmark arguments."""
-        validators = Scenario.get(name)._meta_get("validators", default=[])
+        scenario = Scenario.get(name)
+
+        cls._validate_scenario_args(scenario, name, config)
+
+        validators = scenario._meta_get("validators", default=[])
 
         if not validators:
             return
@@ -169,11 +215,39 @@ class Scenario(plugin.Plugin,
         return self._idle_duration
 
     def add_output(self, additive=None, complete=None):
-        """Add iteration values for additive output.
+        """Add iteration's custom output data.
+
+        This saves custom output data to task results. The main way to get
+        this data processed is to find it in HTML report ("Scenario Data"
+        tab), where it is displayed by tables or various charts (StackedArea,
+        Lines, Pie).
+
+        Take a look at "Processing Output Charts" section of Rally Plugins
+        Reference to find explanations and examples about additive and
+        complete output types and how to display this output data by
+        specific widgets.
+
+        Here is a simple example how to add both additive and complete data
+        and display them by StackedArea widget in HTML report:
+
+        .. code-block:: python
+
+            self.add_output(
+                additive={"title": "Additive data in StackedArea",
+                          "description": "Iterations trend for foo and bar",
+                          "chart_plugin": "StackedArea",
+                          "data": [["foo", 12], ["bar", 34]]},
+                complete={"title": "Complete data as stacked area",
+                          "description": "Data is shown as-is in StackedArea",
+                          "chart_plugin": "StackedArea",
+                          "data": [["foo", [[0, 5], [1, 42], [2, 15]]],
+                                   ["bar", [[0, 2], [1, 1.3], [2, 5]]]],
+                          "label": "Y-axis label text",
+                          "axis_label": "X-axis label text"})
 
         :param additive: dict with additive output
         :param complete: dict with complete output
-        :raises RallyException: When additive or complete has wrong format
+        :raises RallyException: if output has wrong format
         """
         for key, value in (("additive", additive), ("complete", complete)):
             if value:
