@@ -41,6 +41,7 @@ class TempestSetupFailure(exceptions.RallyException):
 
 
 def check_output(*args, **kwargs):
+    debug = kwargs.pop("debug", True)
     kwargs["stderr"] = subprocess.STDOUT
     try:
         output = subprocess.check_output(*args, **kwargs)
@@ -49,7 +50,9 @@ def check_output(*args, **kwargs):
         LOG.error("Error output: '%s'" % encodeutils.safe_decode(e.output))
         raise
 
-    LOG.debug("subprocess output: '%s'" % encodeutils.safe_decode(output))
+    if debug:
+        LOG.debug("Subprocess output: '%s'" % encodeutils.safe_decode(output))
+
     return output
 
 
@@ -189,29 +192,23 @@ class Tempest(object):
             try:
                 check_output(["virtualenv", "-p", sys.executable, ".venv"],
                              cwd=self.path())
-                # NOTE(kun): Using develop mode installation is for run
-                #            multiple tempest instance. However, dependency
-                #            from tempest(os-testr) has issues here, before
-                #            https://review.openstack.org/#/c/207691/ being
-                #            merged, we have to install dependency manually and
-                #            run setup.py with -N(install package without
-                #            dependency)
-                check_output([self.venv_wrapper, "pip", "install", "-r",
-                              "requirements.txt", "-r",
-                              "test-requirements.txt"], cwd=self.path())
-                check_output([self.venv_wrapper, "pip", "install",
-                              "-e", "./"], cwd=self.path())
+                # NOTE(kun): Using develop mode installation is for running
+                #            multiple Tempest instances.
+                check_output([self.venv_wrapper, "pip", "install", "-e", "./"],
+                             cwd=self.path())
             except subprocess.CalledProcessError:
                 if os.path.exists(self.path(".venv")):
                     shutil.rmtree(self.path(".venv"))
-                raise TempestSetupFailure(_("failed to install virtualenv"))
+                raise TempestSetupFailure(_("Failed to install virtualenv."))
 
     def is_configured(self):
         return os.path.isfile(self.config_file)
 
-    def generate_config_file(self, override=False):
-        """Generate configuration file of Tempest for current deployment.
+    def generate_config_file(self, extra_conf=None, override=False):
+        """Generate Tempest configuration file for the current deployment.
 
+        :param extra_conf: A ConfigParser() object with options to
+                           extend/update Tempest config file
         :param override: Whether or not to override existing Tempest
                          config file
         """
@@ -222,7 +219,8 @@ class Tempest(object):
 
             LOG.info(_("Creating Tempest configuration "
                        "file for deployment: %s") % self.deployment)
-            config.TempestConfig(self.deployment).generate(self.config_file)
+            conf = config.TempestConfig(self.deployment)
+            conf.generate(self.config_file, extra_conf)
             LOG.info(_("Tempest configuration file "
                        "has been successfully created!"))
         else:
@@ -272,18 +270,20 @@ class Tempest(object):
                     if not self._is_git_repo(self.base_repo):
                         self._clone()
                     shutil.copytree(self.base_repo, self.path())
-                    if self.version:
-                        cmd = ["git", "checkout", self.version]
-                        subprocess.check_call(cmd, cwd=self.path("tempest"))
+
+                if self.version:
+                    check_output(["git", "checkout", self.version],
+                                 cwd=self.path())
+
                 if not self._system_wide:
                     self._install_venv()
+
                 self._initialize_testr()
             except subprocess.CalledProcessError as e:
                 self.uninstall()
-                raise TempestSetupFailure("failed cmd: '%s'" % e.cmd)
+                raise TempestSetupFailure("Failed cmd: '%s'" % e.cmd)
             else:
                 LOG.info(_("Tempest has been successfully installed!"))
-
         else:
             LOG.info(_("Tempest is already installed."))
 
@@ -303,16 +303,42 @@ class Tempest(object):
                      os.path.basename(self.plugin_source.strip("/")))
         version = self.plugin_version or "master"
         cmd = ["pip", "install", "--no-deps",
-               "--src", self.path("plugins"), "-e",
+               "--src", self.path("plugins/system-wide"), "-e",
                "git+{0}@{1}#egg={2}".format(self.plugin_source, version, egg)]
         if not self._system_wide:
-            cmd.insert(0, self.path("tools/with_venv.sh"))
             cmd.remove("--no-deps")
+            cmd.remove(self.path("plugins/system-wide"))
+            cmd.insert(0, self.path("tools/with_venv.sh"))
+            cmd.insert(4, self.path("plugins"))
         check_output(cmd, cwd=self.path())
         LOG.info(_("Tempest plugin has been successfully installed!"))
 
+    def list_plugins(self):
+        """List all installed Tempest plugins for local Tempest repo."""
+        cmd_list_plugins = ["tempest", "list-plugins"]
+        if not self._system_wide:
+            cmd_list_plugins.insert(0, self.path("tools/with_venv.sh"))
+        else:
+            cmd_pip_list = ["pip", "list"]
+            if "tempest" not in check_output(cmd_pip_list,
+                                             cwd=self.path(), debug=False):
+                return _("Cannot list Tempest plugins because Tempest "
+                         "package is not installed in your environment. "
+                         "Please, install Tempest package and try again.")
+
+        return check_output(cmd_list_plugins, cwd=self.path(), debug=False)
+
+    def uninstall_plugin(self, repo_name):
+        """Uninstall Tempest plugin for local Tempest repo."""
+        repo_path = self.path("plugins/system-wide/%s" % repo_name)
+        if not self._system_wide:
+            repo_path = self.path("plugins/%s" % repo_name)
+        if os.path.exists(repo_path):
+            shutil.rmtree(repo_path)
+
     @logging.log_verification_wrapper(LOG.info, _("Run verification."))
-    def _prepare_and_run(self, set_name, regex, tests_file, concur, failing):
+    def _prepare_and_run(self, set_name, regex, tests_file,
+                         tests_file_to_skip, concur, failing):
         if not self.is_configured():
             self.generate_config_file()
 
@@ -333,6 +359,18 @@ class Tempest(object):
         elif tests_file:
             testr_args = "--load-list %s" % os.path.abspath(tests_file)
 
+        if tests_file_to_skip and not tests_file:
+            tests_to_run = set(self.discover_tests(testr_args))
+            with open(os.path.abspath(tests_file_to_skip), "rb") as f:
+                tests_to_skip = set([line.strip() for line in f])
+            tests_to_run -= tests_to_skip
+
+            temp_file = tempfile.NamedTemporaryFile()
+            with open(temp_file.name, "wb") as f:
+                f.writelines("\n".join(tests_to_run))
+
+            testr_args = "--load-list %s" % temp_file.name
+
         self.verification.start_verifying(set_name)
         try:
             self.run(testr_args, concur=concur)
@@ -388,7 +426,9 @@ class Tempest(object):
 
         :param pattern: Test name pattern which can be used to match
         """
-        cmd = [self.venv_wrapper, "testr", "list-tests", pattern]
+        cmd = ["testr", "list-tests", pattern]
+        if not self._system_wide:
+            cmd.insert(0, self.path("tools/with_venv.sh"))
         raw_results = subprocess.Popen(
             cmd, cwd=self.path(), env=self.env,
             stdout=subprocess.PIPE).communicate()[0]
@@ -415,9 +455,10 @@ class Tempest(object):
         else:
             self.verification.set_failed()
 
-    def verify(self, set_name, regex, tests_file, expected_failures, concur,
-               failing):
-        self._prepare_and_run(set_name, regex, tests_file, concur, failing)
+    def verify(self, set_name, regex, tests_file,
+               tests_file_to_skip, expected_failures, concur, failing):
+        self._prepare_and_run(set_name, regex, tests_file,
+                              tests_file_to_skip, concur, failing)
         self._save_results(expected_failures=expected_failures)
 
     def import_results(self, set_name, log_file):
