@@ -208,10 +208,23 @@ class Cinder(ResourceManager):
             search_opts={"all_tenants": True})
 
 
+class Senlin(ResourceManager):
+
+    REQUIRED_SERVICE = consts.Service.SENLIN
+
+    def list_clusters(self):
+        return self.client.clusters()
+
+    def list_profiles(self):
+        return self.client.profiles()
+
+
 class Watcher(ResourceManager):
 
     REQUIRED_SERVICE = consts.Service.WATCHER
 
+    REPR_KEYS = ("uuid", "name")
+
     def list_audits(self):
         return self.client.audit.list()
 
@@ -221,12 +234,12 @@ class Watcher(ResourceManager):
     def list_goals(self):
         return self.client.goal.list()
 
+    def list_strategies(self):
+        return self.client.strategy.list()
+
     def list_action_plans(self):
         return self.client.action_plan.list()
 
-    def list_actions(self):
-        return self.client.action.list()
-
 
 class CloudResources(object):
     """List and compare cloud resources.
