@@ -205,12 +205,10 @@ def main():
             clients.nova().flavors.delete(flavor.id)
 
         LOG.info("Creating a shared network.")
-        tenant_name = clients.keystone().tenant_name
-        tenant_id = clients.keystone().get_project_id(tenant_name)
         net_body = {
             "network": {
                 "name": "shared-net-%s" % str(uuid.uuid4()),
-                "tenant_id": tenant_id,
+                "tenant_id": clients.keystone.auth_ref.project_id,
                 "shared": True
             }
         }
@@ -255,6 +253,9 @@ def main():
     render_vars["installplugin"] = call_rally(
         "verify installplugin --source %s" % TEMPEST_PLUGIN)
 
+    # List installed Tempest plugins
+    render_vars["listplugins"] = call_rally("verify listplugins")
+
     # Discover tests depending on Tempest suite
     discover_cmd = "verify discover"
     if args.mode == "light":
