@@ -564,7 +564,7 @@ class TaskTestCase(unittest.TestCase):
                "deployment_id": deployment_id})
         results = json.loads(rally("task results"))
         iterations_completed = len(results[0]["result"])
-        self.assertTrue(iterations_completed < times)
+        self.assertLess(iterations_completed, times)
 
     def test_start_abort_on_sla_failure_max_seconds_constant(self):
         times = 100
@@ -734,7 +734,7 @@ class TaskTestCase(unittest.TestCase):
         iterations_completed = len(results[0]["result"])
         # NOTE(msdubov): check that the task is really stopped before
         #                the specified number of iterations
-        self.assertTrue(iterations_completed < RUNNER_TIMES)
+        self.assertLess(iterations_completed, RUNNER_TIMES)
         self.assertIn("aborted", rally("task status"))
         report = rally.gen_report_path(extension="html")
         rally("task report --out %s" % report)
@@ -980,3 +980,50 @@ class SLAExtraFlagsTestCase(unittest.TestCase):
                                    "times": 5,
                                    "rps": 3,
                                    "timeout": 6})
+
+
+class SLAPerfDegrTestCase(unittest.TestCase):
+
+    def _get_sample_task_config(self, max_degradation=500):
+        return {
+            "Dummy.dummy_random_action": [
+                {
+                    "args": {
+                        "actions_num": 5,
+                        "sleep_min": 0.5,
+                        "sleep_max": 2
+                    },
+                    "runner": {
+                        "type": "constant",
+                        "times": 10,
+                        "concurrency": 5
+                    },
+                    "sla": {
+                        "performance_degradation": {
+                            "max_degradation": max_degradation
+                        }
+                    }
+                }
+            ]
+        }
+
+    def test_sla_fail(self):
+        rally = utils.Rally()
+        cfg = self._get_sample_task_config(max_degradation=1)
+        config = utils.TaskConfig(cfg)
+        rally("task start --task %s" % config.filename)
+        self.assertRaises(utils.RallyCliError, rally, "task sla_check")
+
+    def test_sla_success(self):
+        rally = utils.Rally()
+        config = utils.TaskConfig(self._get_sample_task_config())
+        rally("task start --task %s" % config.filename)
+        rally("task sla_check")
+        expected = [
+            {"benchmark": "Dummy.dummy_random_action",
+             "criterion": "performance_degradation",
+             "detail": mock.ANY,
+             "pos": 0, "status": "PASS"},
+        ]
+        data = rally("task sla_check --json", getjson=True)
+        self.assertEqual(expected, data)
