@@ -482,7 +482,7 @@ class TimeoutThreadTestCase(test.TestCase):
         # NOTE(sskripnick): Killing thread with PyThreadState_SetAsyncExc
         # works with sinificant delay. Make sure this delay is less
         # than 10 seconds.
-        self.assertTrue(time_elapsed < 11,
+        self.assertLess(time_elapsed, 11,
                         "Thread killed too late (%s seconds)" % time_elapsed)
 
 
@@ -548,3 +548,42 @@ class LockedDictTestCase(test.TestCase):
         self.assertEqual(({"foo": "bar", "spam": {"a": ("b", {"c": "d"})}},),
                          args)
         self.assertEqual({"memo": "foo_memo"}, kw)
+
+
+@ddt.ddt
+class FloatFormatterTestCase(test.TestCase):
+
+    @ddt.data(
+        {
+            "num_float": 0,
+            "num_str": "0.0"
+        },
+        {
+            "num_float": 37,
+            "num_str": "37.0"
+        },
+        {
+            "num_float": 0.0000001,
+            "num_str": "0.0"
+        },
+        {
+            "num_float": 0.000000,
+            "num_str": "0.0"
+        },
+        {
+            "num_float": 1.0000001,
+            "num_str": "1.0"
+        },
+        {
+            "num_float": 1.0000011,
+            "num_str": "1.000001"
+        },
+        {
+            "num_float": 1.0000019,
+            "num_str": "1.000002"
+        }
+
+    )
+    @ddt.unpack
+    def test_format_float_to_str(self, num_float, num_str):
+        self.assertEquals(num_str, utils.format_float_to_str(num_float))
\ No newline at end of file
