@@ -756,6 +756,44 @@ class FuelEnvironmentTestCase(test.TestCase):
         self.assertEqual(envs[:-1], fres.list())
 
 
+class SenlinMixinTestCase(test.TestCase):
+
+    def test_id(self):
+        senlin = resources.SenlinMixin()
+        senlin.raw_resource = {"id": "TEST_ID"}
+        self.assertEqual("TEST_ID", senlin.id())
+
+    def test__manager(self):
+        senlin = resources.SenlinMixin()
+        senlin._service = "senlin"
+        senlin.user = mock.MagicMock()
+        self.assertEqual(senlin.user.senlin.return_value, senlin._manager())
+
+    def test_list(self):
+        senlin = resources.SenlinMixin()
+        senlin._service = "senlin"
+        senlin.user = mock.MagicMock()
+        senlin._resource = "some_resources"
+
+        some_resources = [{"name": "resource1"}, {"name": "resource2"}]
+        senlin.user.senlin().some_resources.return_value = some_resources
+
+        self.assertEqual(some_resources, senlin.list())
+        senlin.user.senlin().some_resources.assert_called_once_with()
+
+    def test_delete(self):
+        senlin = resources.SenlinMixin()
+        senlin._service = "senlin"
+        senlin.user = mock.MagicMock()
+        senlin._resource = "some_resources"
+        senlin.raw_resource = {"id": "TEST_ID"}
+        senlin.user.senlin().delete_some_resource.return_value = None
+
+        senlin.delete()
+        senlin.user.senlin().delete_some_resource.assert_called_once_with(
+            "TEST_ID")
+
+
 class WatcherTemplateTestCase(test.TestCase):
 
     def test_id(self):
@@ -780,3 +818,65 @@ class WatcherTemplateTestCase(test.TestCase):
 
         self.assertEqual("audit_template", watcher._resource)
         watcher._manager().list.assert_called_once_with(limit=0)
+
+
+class WatcherAuditTestCase(test.TestCase):
+
+    def test_id(self):
+        watcher = resources.WatcherAudit()
+        watcher.raw_resource = mock.MagicMock(uuid=100)
+        self.assertEqual(100, watcher.id())
+
+    def test_name(self):
+        watcher = resources.WatcherAudit()
+        watcher.raw_resource = mock.MagicMock(uuid="name")
+        self.assertEqual("name", watcher.name())
+
+    @mock.patch("%s.WatcherAudit._manager" % BASE)
+    def test_is_deleted(self, mock__manager):
+        mock__manager.return_value.get.return_value = None
+        watcher = resources.WatcherAudit()
+        watcher.id = mock.Mock()
+        self.assertFalse(watcher.is_deleted())
+        mock__manager.side_effect = [watcher_exceptions.NotFound()]
+        self.assertTrue(watcher.is_deleted())
+
+    def test_list(self):
+        watcher = resources.WatcherAudit()
+        watcher._manager = mock.MagicMock()
+
+        watcher.list()
+
+        self.assertEqual("audit", watcher._resource)
+        watcher._manager().list.assert_called_once_with(limit=0)
+
+
+class WatcherActionPlanTestCase(test.TestCase):
+
+    def test_id(self):
+        watcher = resources.WatcherActionPlan()
+        watcher.raw_resource = mock.MagicMock(uuid=100)
+        self.assertEqual(100, watcher.id())
+
+    def test_name(self):
+        watcher = resources.WatcherActionPlan()
+        watcher.raw_resource = mock.MagicMock(uuid="name")
+        self.assertEqual("name", watcher.name())
+
+    @mock.patch("%s.WatcherActionPlan._manager" % BASE)
+    def test_is_deleted(self, mock__manager):
+        mock__manager.return_value.get.return_value = None
+        watcher = resources.WatcherActionPlan()
+        watcher.id = mock.Mock()
+        self.assertFalse(watcher.is_deleted())
+        mock__manager.side_effect = [watcher_exceptions.NotFound()]
+        self.assertTrue(watcher.is_deleted())
+
+    def test_list(self):
+        watcher = resources.WatcherActionPlan()
+        watcher._manager = mock.MagicMock()
+
+        watcher.list()
+
+        self.assertEqual("action_plan", watcher._resource)
+        watcher._manager().list.assert_called_once_with(limit=0)
\ No newline at end of file
