@@ -377,8 +377,10 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
         for key in self.deployment:
             self.assertEqual(ret[key], self.deployment[key])
 
+    @mock.patch("rally.osclients.Clients.services")
     @mock.patch("rally.osclients.Keystone.create_client")
-    def test_deployment_check(self, mock_keystone_create_client):
+    def test_deployment_check(self, mock_keystone_create_client,
+                              mock_clients_services):
         sample_credential = objects.Credential("http://192.168.1.1:5000/v2.0/",
                                                "admin",
                                                "adminpass").to_dict()
@@ -386,6 +388,7 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
                       "users": [sample_credential]}
         api.Deployment.check(deployment)
         mock_keystone_create_client.assert_called_with()
+        mock_clients_services.assert_called_once_with()
 
     def test_deployment_check_raise(self):
         sample_credential = objects.Credential("http://192.168.1.1:5000/v2.0/",
@@ -427,7 +430,8 @@ class VerificationAPITestCase(BaseDeploymentTestCase):
 
         self.tempest.verify.assert_called_once_with(
             set_name="smoke", regex=None, tests_file=None,
-            expected_failures=None, concur=0, failing=False)
+            tests_file_to_skip=None, expected_failures=None,
+            concur=0, failing=False)
 
     @mock.patch("os.path.exists", return_value=True)
     @mock.patch("rally.api.objects.Deployment.get")
@@ -444,7 +448,8 @@ class VerificationAPITestCase(BaseDeploymentTestCase):
 
         self.tempest.verify.assert_called_once_with(
             set_name="", regex=None, tests_file=tests_file,
-            expected_failures=None, concur=0, failing=False)
+            tests_file_to_skip=None, expected_failures=None,
+            concur=0, failing=False)
 
     @mock.patch("rally.api.objects.Deployment.get")
     @mock.patch("rally.api.objects.Verification")
@@ -515,6 +520,23 @@ class VerificationAPITestCase(BaseDeploymentTestCase):
                                                 "/tmp/fake/plugin")
         self.tempest.install_plugin.assert_called_once_with()
 
+    @mock.patch("os.path.exists", return_value=True)
+    @mock.patch("rally.common.objects.Deployment.get")
+    @mock.patch("rally.verification.tempest.tempest.Tempest")
+    def test_list_tempest_plugins(
+            self, mock_tempest, mock_deployment_get, mock_exists):
+        mock_tempest.return_value = self.tempest
+        api.Verification.list_tempest_plugins(self.deployment_uuid)
+        self.tempest.list_plugins.assert_called_once_with()
+
+    @mock.patch("rally.common.objects.Deployment.get")
+    @mock.patch("rally.verification.tempest.tempest.Tempest")
+    def test_uninstall_tempest_plugin(self, mock_tempest, mock_deployment_get):
+        mock_tempest.return_value = self.tempest
+        api.Verification.uninstall_tempest_plugin(self.deployment_uuid,
+                                                  "fake-plugin")
+        self.tempest.uninstall_plugin.assert_called_once_with("fake-plugin")
+
     @mock.patch("os.path.exists", return_value=True)
     @mock.patch("rally.common.objects.Deployment.get")
     @mock.patch("rally.verification.tempest.tempest.Tempest")
@@ -531,7 +553,7 @@ class VerificationAPITestCase(BaseDeploymentTestCase):
             self, mock_tempest, mock_deployment_get, mock_exists):
         mock_tempest.return_value = self.tempest
         api.Verification.configure_tempest(self.deployment_uuid)
-        self.tempest.generate_config_file.assert_called_once_with(False)
+        self.tempest.generate_config_file.assert_called_once_with(None, False)
 
     @mock.patch("os.path.exists", return_value=False)
     @mock.patch("rally.common.objects.Deployment.get")
