@@ -98,8 +98,8 @@ class TempestUtilsTestCase(BaseTestCase):
     @mock.patch("os.path.isdir", return_value=False)
     @mock.patch("%s.tempest.check_output" % TEMPEST_PATH,
                 return_value="some_output")
-    def test__venv_install_when_venv_not_exist(self, mock_check_output,
-                                               mock_isdir, mock_sys):
+    def test__venv_install_when_venv_does_not_exist(self, mock_check_output,
+                                                    mock_isdir, mock_sys):
         mock_sys.version_info = "not_py27_env"
         self.verifier._install_venv()
 
@@ -107,11 +107,8 @@ class TempestUtilsTestCase(BaseTestCase):
         mock_check_output.assert_has_calls([
             mock.call(["virtualenv", "-p", mock_sys.executable, ".venv"],
                       cwd="/tmp"),
-            mock.call(["/tmp/tools/with_venv.sh", "pip", "install", "-r",
-                       "requirements.txt", "-r", "test-requirements.txt"],
-                      cwd="/tmp"),
-            mock.call(["/tmp/tools/with_venv.sh", "pip", "install",
-                       "-e", "./"], cwd="/tmp"),
+            mock.call(["/tmp/tools/with_venv.sh", "pip",
+                       "install", "-e", "./"], cwd="/tmp")
         ])
 
     @mock.patch("%s.tempest.sys" % TEMPEST_PATH)
@@ -235,16 +232,15 @@ class TempestInstallAndUninstallTestCase(BaseTestCase):
     @mock.patch(TEMPEST_PATH + ".tempest.Tempest.base_repo")
     @mock.patch(TEMPEST_PATH + ".tempest.Tempest._initialize_testr")
     @mock.patch(TEMPEST_PATH + ".tempest.Tempest._install_venv")
-    @mock.patch(TEMPEST_PATH + ".tempest.subprocess.check_call")
+    @mock.patch(TEMPEST_PATH + ".tempest.check_output")
     @mock.patch("shutil.copytree")
     @mock.patch(TEMPEST_PATH + ".tempest.Tempest._clone")
     @mock.patch("os.path.exists", return_value=False)
     @mock.patch(TEMPEST_PATH + ".tempest.Tempest._is_git_repo",
                 return_value=False)
     def test_install_successful(self, mock_tempest__is_git_repo, mock_exists,
-                                mock_tempest__clone,
-                                mock_copytree, mock_check_call,
-                                mock_tempest__install_venv,
+                                mock_tempest__clone, mock_copytree,
+                                mock_check_output, mock_tempest__install_venv,
                                 mock_tempest__initialize_testr,
                                 mock_tempest_base_repo):
         mock_tempest_base_repo.__get__ = mock.Mock(return_value="fake_dir")
@@ -259,9 +255,9 @@ class TempestInstallAndUninstallTestCase(BaseTestCase):
         mock_copytree.assert_called_once_with(
             self.verifier.base_repo,
             self.verifier.path())
-        cwd = self.verifier.path("tempest")
+        cwd = self.verifier.path()
         expected = [mock.call(["git", "checkout", "3f4c8d44"], cwd=cwd)]
-        self.assertEqual(expected, mock_check_call.mock_calls)
+        self.assertEqual(expected, mock_check_output.mock_calls)
         mock_tempest__install_venv.assert_called_once_with()
         mock_tempest__initialize_testr.assert_called_once_with()
 
@@ -342,6 +338,21 @@ class TempestInstallPluginsTestCase(BaseTestCase):
         mock_tempest_check_output.assert_called_with(cmd,
                                                      cwd=self.verifier.path())
 
+    @mock.patch(TEMPEST_PATH + ".tempest.check_output")
+    def test_list_plugins(self, mock_tempest_check_output):
+        self.verifier.list_plugins()
+
+        cmd = [self.verifier.venv_wrapper, "tempest", "list-plugins"]
+        mock_tempest_check_output.assert_called_with(
+            cmd, cwd=self.verifier.path(), debug=False)
+
+    @mock.patch("shutil.rmtree")
+    @mock.patch("os.path.exists")
+    def test_uninstall_plugin(self, mock_exists, mock_rmtree):
+        self.verifier.uninstall_plugin("fake-plugin")
+        mock_rmtree.assert_called_once_with(
+            self.verifier.path("plugins/fake-plugin"))
+
 
 class TempestVerifyTestCase(BaseTestCase):
     def _get_fake_call(self, testr_args,
@@ -358,7 +369,7 @@ class TempestVerifyTestCase(BaseTestCase):
     @mock.patch(TEMPEST_PATH + ".config.TempestConfig")
     def test_verify_no_tempest_config_exists(self, mock_tempest_config):
         self.assertRaises(exceptions.NotFoundException, self.verifier.verify,
-                          "compute", None, None, None, 0, False)
+                          "compute", None, None, None, None, 0, False)
 
     @mock.patch(TEMPEST_PATH + ".tempest.Tempest.parse_results",
                 return_value=None)
@@ -372,7 +383,7 @@ class TempestVerifyTestCase(BaseTestCase):
         set_name = "identity"
         fake_call = self._get_fake_call("tempest.api.%s" % set_name)
 
-        self.verifier.verify(set_name, None, None, None, 0, False)
+        self.verifier.verify(set_name, None, None, None, None, 0, False)
         self.verifier.verification.start_verifying.assert_called_once_with(
             set_name)
 
@@ -394,7 +405,7 @@ class TempestVerifyTestCase(BaseTestCase):
         fake_call = self._get_fake_call("tempest.api.%s" % set_name)
         mock_subprocess.side_effect = subprocess.CalledProcessError
 
-        self.verifier.verify(set_name, None, None, None, 0, False)
+        self.verifier.verify(set_name, None, None, None, None, 0, False)
         self.verifier.verification.start_verifying.assert_called_once_with(
             set_name)
 
@@ -416,7 +427,32 @@ class TempestVerifyTestCase(BaseTestCase):
         tests_file = "/path/to/tests/file"
         fake_call = self._get_fake_call("--load-list %s" % tests_file)
 
-        self.verifier.verify("", None, tests_file, None, 0, False)
+        self.verifier.verify("", None, tests_file, None, None, 0, False)
+        self.verifier.verification.start_verifying.assert_called_once_with("")
+
+        mock_subprocess.check_call.assert_called_once_with(
+            fake_call, env=mock_tempest_env, cwd=self.verifier.path(),
+            shell=True)
+        mock_tempest_parse_results.assert_called_once_with(None, None)
+
+    @mock.patch(TEMPEST_PATH + ".tempest.Tempest.parse_results",
+                return_value=None)
+    @mock.patch(TEMPEST_PATH + ".tempest.Tempest.env")
+    @mock.patch(TEMPEST_PATH + ".tempest.subprocess")
+    @mock.patch(TEMPEST_PATH + ".config.TempestResourcesContext")
+    @mock.patch("os.path.isfile", return_value=True)
+    @mock.patch("tempfile.NamedTemporaryFile", return_value=mock.MagicMock())
+    @mock.patch("six.moves.builtins.open", side_effect=mock.mock_open())
+    def test_verify_tests_file_to_skip_specified(
+            self, mock_open, mock_named_temporary_file, mock_isfile,
+            mock_tempest_resources_context, mock_subprocess, mock_tempest_env,
+            mock_tempest_parse_results):
+        mock_named_temporary_file.return_value.name = "some-file-name"
+        fake_call = self._get_fake_call("--load-list some-file-name")
+
+        tests_file_to_skip = "/path/to/tests/file"
+        self.verifier.verify(
+            "", None, None, tests_file_to_skip, None, 0, False)
         self.verifier.verification.start_verifying.assert_called_once_with("")
 
         mock_subprocess.check_call.assert_called_once_with(
@@ -437,7 +473,7 @@ class TempestVerifyTestCase(BaseTestCase):
         fake_call = self._get_fake_call(
             "tempest.api.%s" % set_name, "--concurrency 1")
 
-        self.verifier.verify("identity", None, None, None, 1, False)
+        self.verifier.verify("identity", None, None, None, None, 1, False)
         self.verifier.verification.start_verifying.assert_called_once_with(
             set_name)
 
@@ -458,7 +494,7 @@ class TempestVerifyTestCase(BaseTestCase):
         set_name = "identity"
         fake_call = self._get_fake_call("tempest.api.%s" % set_name)
 
-        self.verifier.verify("identity", None, None, None, 0, False)
+        self.verifier.verify("identity", None, None, None, None, 0, False)
         self.verifier.verification.start_verifying.assert_called_once_with(
             set_name)
 
@@ -478,7 +514,7 @@ class TempestVerifyTestCase(BaseTestCase):
                                       mock_subprocess, mock_tempest_env,
                                       mock_tempest_parse_results):
         fake_call = self._get_fake_call("--failing")
-        self.verifier.verify("", None, None, None, 0, True)
+        self.verifier.verify("", None, None, None, None, 0, True)
 
         self.verifier.verification.start_verifying.assert_called_once_with(
             "re-run-failed")
